#!/usr/bin/env bash

# Check JAVA_HOME
if [[ ! -d "${JAVA_HOME}" ]]; then
	echo "Java not detected ! Please set environment variable JAVA_HOME before launching,"
	echo "or edit the file 'tutti-export.sh' and insert this line :"
	echo " export JAVA_HOME=<path_to_java>"
	exit 1
fi

# APP variables
APP_BASEDIR="$( cd "$( dirname "${0}" )" >/dev/null && pwd )"
APP_CONF_FILE="${APP_BASEDIR}/conf/tutti-export.config"
APP_CLASSPATH="tutti-export-5.2.8-tools.jar:lib/*"

# JAVA variables
JAVA_COMMAND="${JAVA_HOME}/bin/java"
JAVA_OPTS="-Xmx1024M"
if [[ ! -z "${TNS_ADMIN}" ]]; then
	JAVA_OPTS="${JAVA_OPTS} -Doracle.net.tns_admin=${TNS_ADMIN}"
fi

if [[ ! -z "${LOG4J_FILE}" ]]; then
	JAVA_OPTS="${JAVA_OPTS} -Dlog4j.configuration=file:${LOG4J_FILE}"
fi

# print messages
echo "Allegro Campagne :: Export"
echo "- basedir:  ${APP_BASEDIR}"
echo "- jre home: ${JAVA_HOME}"
echo "- java bin : ${JAVA_COMMAND}"
echo "- config file: ${APP_CONF_FILE}"

# goto export.sh directory
cd ${APP_BASEDIR}

# execute export
${JAVA_COMMAND} ${JAVA_OPTS} -Dtutti-export.config=${APP_CONF_FILE} -Dtutti.basedir=${APP_BASEDIR} -jar tutti-export-5.2.8.jar "$@"
# retrieve exit code
EXIT_CODE=$?
echo "Stop Allegro Campagne :: Export with exit code: ${EXIT_CODE}"
exit ${EXIT_CODE}
